==> haskell-warp-quic-0.0.0-340-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-BAUOM34E8qfH6GQLX77RdJ
key:                  warp-quic-0.0.0-BAUOM34E8qfH6GQLX77RdJ
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  6679fba42badd233d23191f3eb2f7bf2
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-BAUOM34E8qfH6GQLX77RdJ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http3-0.0.5-1xFjfxGRSnT8lmS800SPgB
    quic-0.1.16-E3PZhqmI9ch65vmaaWKEdr tls-2.0.6-CzoL7kyWs3bDh9mXYMHbfb
    wai-3.2.4-84onj9aucoXBC5yY5F84Os warp-3.3.30-9Zxn2kwWyMQK8cAG5JiXwE

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-quic-0.0.0-343-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-HoE2pcGriC6FM74U97JlJp
key:                  warp-quic-0.0.0-HoE2pcGriC6FM74U97JlJp
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  538a1c5b72c0bb23f4d8ae198b29a69f
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-HoE2pcGriC6FM74U97JlJp
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http3-0.0.5-Ei44B6dQM8G1YP92N69Y1V
    quic-0.1.17-G8bwS7FoQe2AbP7uyoyoHc tls-2.0.6-L66KOQBFJindZNRhTNL8r
    wai-3.2.4-2xkfe4HZLaM7fVTIVWFd6J warp-3.3.30-HIDLsUqSiJ7GvzYeI38eeS

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
